@@ -65,9 +65,9 @@ class wxDialog1(wx.Dialog):
 
       <td style="text-align: center; vertical-align: middle;">
 
-      <div style="text-align: center;">Model Builder 0.4.4<br>
+      <div style="text-align: center;">Model Builder 0.4.5<br>
 
-January, 2008<br>
+December, 2008<br>
 
       </div>
 
@@ -75,7 +75,7 @@ January, 2008<br>
 
       </td>
 
-      <td style="vertical-align: top;"><img src="http://www.procc.fiocruz.br/procc/Members/flavio/flavio" title="" alt="" style="width: 100px; height: 100px;"><br>
+      <td style="vertical-align: top;"><img src="http://fccoelho.googlepages.com/flavio.jpg" title="" alt="" style="width: 100px; height: 100px;"><br>
 
       </td>
 
