@@ -53,6 +53,7 @@ import PlotFigure as PF
 from BIP.Bayes import Melding as meld
 from time import *
 import icones
+import MBicon
 import quivVarFrame as QF
 from BIP.Bayes import lhs
 
@@ -321,7 +322,7 @@ class wxFrame1(wx.Frame):
         self.SetAutoLayout(True)
         self.SetInitialSize(wx.Size(730, 480))
         self.SetMaxSize(wx.Size(730, 480))
-        self.SetIcon(wx.Icon('MB.ico',wx.BITMAP_TYPE_ICO))
+        self.SetIcon(MBicon.MB.GetIcon())#wx.Icon(MBicon.MB.GetIcon(),wx.BITMAP_TYPE_ICO))
         self.Bind(wx.EVT_CLOSE, self.OnWxFrame1Close)
 
         self.statusBar1 = wx.StatusBar(id=wxID_WXFRAME1STATUSBAR1,
